@@ -34,11 +34,11 @@ sub qtest {
 
   my $q0 = eval { $sub->($qstr0); };
   my $q1 = eval { $sub->($qstr1); };
-  if ($q0->can('toHash') && $q1->can('toHash')) {
+  if (UNIVERSAL::can($q0,'toHash') && UNIVERSAL::can($q1,'toHash')) {
     $q0 = $q0->toHash;
     $q1 = $q1->toHash;
   }
-  elsif ($q0->can('toJson') && $q1->can('toJson')) {
+  elsif (UNIVERSAL::can($q0,'toJson') && UNIVERSAL::can($q1,'toJson')) {
     $q0 = $q0->toJson;
     $q1 = $q1->toJson;
   }
